@@ -390,6 +390,11 @@ class TranslateNodeTemplates(object):
         for resource in to_remove:
             self.hot_resources.remove(resource)
 
+        for resource in self.hot_resources:
+            for removed_resource in to_remove:
+                if removed_resource in resource.depends_on:
+                    resource.depends_on.remove(removed_resource)
+
         return self.hot_resources
 
     def translate_param_value(self, param_value, resource):
@@ -409,7 +414,7 @@ class TranslateNodeTemplates(object):
                                             tosca_template)
             if tosca_target:
                 prop_value = tosca_target.get_property_value(prop_name)
-                if prop_value:
+                if prop_value is not None:
                     prop_value = self.translate_param_value(
                         prop_value, resource)
                     return self._unfold_value(prop_value, prop_arg)
